SmdhIcon class
Quadratic Z-shaped image with tiles.
For convenience, methods and fields of this class use the classical x-y coordinate system and uses the Z-shaped coordinate system internally.
Constructors
Properties
- buffer → ByteData
-
Low-level access to the underlying buffer.
final
- endianness → Endian
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- pixels → int
-
The total amount of pixels.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → int
-
The amount of pixels in each direction.
no setter
- tileSize → int
-
The size of each tile.
final
Methods
-
getPixelAt(
int x, int y) → Rgb565 - Returns the RGB pixel at the given coordinate.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setPixelAt(
int x, int y, Rgb565 pixel) → void - Set the RGB pixel at the given coordinate.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override