Rgb565 class
A 16-bit color.
Constructors
- Rgb565(int red, int green, int blue)
- Rgb565.fromInt(int value)
- Rgb565.fromRgb888(int r, int g, int b)
Properties
- blue ↔ int
-
The blue value in the range 0 - 2^5.
latefinal
- green ↔ int
-
The green value in the range 0 - 2^6.
latefinal
- hashCode → int
-
The hash code for this object.
no setteroverride
- red ↔ int
-
The red value in the range 0 - 2^5.
latefinal
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toInt(
) → int - Returns the 16-bit integer representation of this color.
-
toRgb888(
) → ({int b, int g, int r}) - Converts the RGB565 color to the closest representable RGB888 color.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override